%bcond_without gtk

%bcond_without meson

Name: audacious
Version: 4.4
Release: 3%{?dist}

%global tar_ver %{version}
%global aud_ver 4.4


License: BSD
Summary: Advanced audio player
URL: https://audacious-media-player.org/
Group: Applications/Multimedia

Source0: https://distfiles.audacious-media-player.org/%{name}-%{tar_ver}.tar.bz2

BuildRequires: libappstream-glib

BuildRequires: gcc-c++
BuildRequires: gettext
%{?with_gtk:BuildRequires: pkgconfig(gtk+-3.0) >= 3.22}
BuildRequires: pkgconfig(glib-2.0)
BuildRequires: desktop-file-utils
BuildRequires: meson
BuildRequires: make

BuildRequires: qt6-qtbase-devel
BuildRequires: pkgconfig(Qt6Core)
BuildRequires: pkgconfig(Qt6Gui)
BuildRequires: pkgconfig(Qt6Widgets)
BuildRequires: pkgconfig(Qt6Svg)

Requires: audacious-libs = %{version}-%{release}

Requires: audacious-plugins >= %{aud_ver}

Requires: hicolor-icon-theme
Requires: gnome-icon-theme
Requires: qt6-qtsvg

Provides: xmms-gui

%description
Audacious is an open source audio player

A descendant of XMMS, Audacious plays your music how you want it, without
stealing away your computer’s resources from other tasks. Drag and drop
folders and individual song files, search for artists and albums in your
entire music library, or create and edit your own custom playlists. Listen
to CDs or stream music from the Internet. Tweak the sound with the
graphical equalizer or change the dynamic range with audio effects. Enjoy
the modern Qt-themed interface or change things up with Winamp Classic
skins. Use the plugins included with Audacious to fetch lyrics for your
music, display a VU meter, and more.

An alternative GTK3-based user interface can still be chosen, too.


%package libs
Summary: Library files for the Audacious audio player
Group: System Environment/Libraries
%global aud_plugin_api 48
%global aud_plugin_api_min 48
Provides: audacious(plugin-api) = %{aud_plugin_api}

%description libs
Library files for the Audacious audio player.


%package devel
Summary: Development files for the Audacious audio player
Group: Development/Libraries
Requires: %{name}-libs = %{version}-%{release}
Requires: pkgconfig(glib-2.0)
%{?with_gtk:Requires: pkgconfig(gtk+-3.0)}

%description devel
Files needed when building software for the Audacious audio player.


%prep
%autosetup -p1 -n %{name}-%{tar_ver}

api=$(grep '[ ]*#define[ ]*_AUD_PLUGIN_VERSION[ ]\+' src/libaudcore/plugin.h | sed 's!.*_AUD_PLUGIN_VERSION[ ]*\([0-9]\+\).*!\1!')
[ "${api}" == "%{aud_plugin_api}" ] || exit -1
api_min=$(grep '[ ]*#define[ ]*_AUD_PLUGIN_VERSION_MIN' src/libaudcore/plugin.h | sed 's!.*_AUD_PLUGIN_VERSION_MIN[ ]*\([0-9]\+\).*!\1!')
[ "${api_min}" == "%{aud_plugin_api_min}" ] || exit -1

%if %{without meson}
sed -i '\,^.SILENT:,d' buildsys.mk.in
sed -i 's!MAKE} -s!MAKE} !' buildsys.mk.in
%endif


%build

%if %{with meson}
%meson \
    -Dqt=true \
    -Dgtk=%{?with_gtk:true}%{!?with_gtk:false} \
    -Dlibarchive=false \
    -Dbuildstamp="OpenCloudOS package"
%meson_build
%else
%configure  \
    %{?with_gtk:--enable-gtk} \
    %{!?with_gtk:--disable-gtk} \
    --disable-libarchive \
    --with-buildstamp="OpenCloudOS package"  \
    --disable-silent-rules \
    --disable-rpath \
    --disable-dependency-tracking
make %{?_smp_mflags}
%endif


%install
%if %{with meson}
%meson_install
%else
%make_install INSTALL="install -p" LIB_PATCH=0
%endif
find %{buildroot} -type f -name "*.la" -exec rm -f {} ';'

%find_lang %{name}


desktop-file-install  \
    --dir %{buildroot}%{_datadir}/applications  \
    %{buildroot}%{_datadir}/applications/audacious.desktop

install -D -m0644 contrib/%{name}.appdata.xml %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml


%post -p /sbin/ldconfig libs
%postun -p /sbin/ldconfig libs


%files -f %{name}.lang
%doc AUTHORS
%{_bindir}/audacious
%{_bindir}/audtool
%{_datadir}/audacious/
%{_mandir}/man[^3]/*
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}*.*
%{_datadir}/appdata/%{name}.appdata.xml

%files libs
%license COPYING
%{_libdir}/*.so.*

%files devel
%{_includedir}/audacious/
%{_includedir}/libaudcore/
%{_includedir}/libaudqt/
%{?with_gtk:%{_includedir}/libaudgui/}
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc


%changelog
* Mon Nov 4 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.4-3
- [Type] other
- [DESC] Rebuild

* Tue Oct 29 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.4-2
- [Type] other
- [DESC] Rebuild

* Wed Sep 25 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.4-1
- initial build
